==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Wir möchten Dich informieren, dass %s den Kalender »%s« veröffentlicht hat.",
    "Open »%s«" : "»%s« öffnen",
    "Cheers!" : "Noch einen schönen Tag!",
    "Recipient" : "Empfänger",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} Fehler)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "Individual" : "Einzelperson",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), es wird auf UTC geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neues Ereignis",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "Email has been sent." : "E-Mail versandt",
    "There was an issue while sending your email." : "Beim Versand der E-Mail ist ein Fehler aufgetreten",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "Wenn geteilt, zeige das vollständige Ereignis an",
    "When shared show only busy" : "wenn geteilt, zeige nur den Status 'beschäftigt' an",
    "When shared hide this event" : "Wenn geteilt, zeige das Ereignis nicht an",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgesagt",
    "Please add a title." : "Bitte einen Titel hinzufügen.",
    "Please select a calendar." : "Bitte einen Kalender auswählen.",
    "The event can not end before it starts." : "Das Ereignis endet bevor es startet.",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "Jeden Tag",
    "Every week" : "Jede Woche",
    "Every month" : "Jeden Monat",
    "Every year" : "Jedes Jahr",
    "never" : "Niemals",
    "after" : "Nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn du damit beginnen würdest einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Ereignisses",
    "5 minutes before" : "5 Minuten vorher",
    "10 minutes before" : "10 Minuten vorher",
    "15 minutes before" : "15 Minuten vorher",
    "30 minutes before" : "30 Minuten vorher",
    "1 hour before" : "1 Stunde vorher",
    "2 hours before" : "2 Stunden vorher",
    "Custom" : "Benutzerdefiniert",
    "Audio" : "Audio",
    "Email" : "E-Mail",
    "Pop-up" : "Pop-up",
    "sec" : "Sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported {imported} objects" : "Erfolgreich {imported} Objekte importiert ",
    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} von {all} importiert, ein Duplikat übersprungen",
    "Imported {imported} out of {all}, one failure" : "{imported} von {all} importiert, ein Fehler",
    "Imported {imported} out of {all}, {errors} failures" : "{imported} von {all} importiert, {errors} Fehler",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {duplicates} Duplikate übersprungen",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {errors} Fehler, {duplicates} Duplikate übersprungen",
    "Audio alarm {time} before the event starts" : "Audio-Alarm {time} bevor das Ereignis startet",
    "Pop-up {time} before the event starts" : "Pop-Up-Meldung {time} bevor das Ereignis startet",
    "Email {time} before the event starts" : "E-Mail {time} bevor das Ereignis startet",
    "None {time} before the event starts" : "Keine Aktion {time} bevor das Ereignis startet",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
    "Audio alarm {time} before the event ends" : "Audio-Alarm {time} bevor das Ereignis endet",
    "Pop-up {time} before the event ends" : "Pop-Up-Meldung {time} bevor das Ereignis endet",
    "Email {time} before the event ends" : "E-Mail {time} bevor das Ereignis endet",
    "None {time} before the event ends" : "Keine Aktion {time} bevor das Ereignis endet",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
    "Audio alarm {time} after the event starts" : "Audio-Alarm {time} nachdem das Ereignis startet",
    "Pop-up {time} after the event starts" : "Pop-Up-Meldung {time} nachdem das Ereignis startet",
    "Email {time} after the event starts" : "E-Mail {time} nachdem das Ereignis startet",
    "None {time} after the event starts" : "Keine Aktion {time} nachdem das Ereignis startet",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
    "Audio alarm {time} after the event ends" : "Audio-Alarm {time} nachdem das Ereignis endete",
    "Pop-up {time} after the event ends" : "Pop-Up-Meldung {time} nachdem das Ereignis endete",
    "Email {time} after the event ends" : "E-Mail {time} nachdem das Ereignis endete",
    "None {time} after the event ends" : "Keine Aktion {time} nachdem das Ereignis endete",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
    "Audio alarm at the event's start" : "Audio-Alarm beim Start des Ereignisses",
    "Pop-up at the event's start" : "Pop-Up-Meldung beim Start des Ereignisses",
    "Email at the event's start" : "E-Mail beim Start des Ereignisses",
    "None at the event's start" : "Keine Aktion beim Start des Ereignisses",
    "{type} at the event's start" : "{type} zu Beginn der Ereignisses",
    "Audio alarm at the event's end" : "Audio-Alarm beim Ende des Ereignisses",
    "Pop-up at the event's end" : "Pop-Up-Meldung beim Ende des Ereignisses",
    "Email at the event's end" : "E-Mail beim Ende des Ereignisses",
    "None at the event's end" : "Keine Aktion beim Ende des Ereignisses",
    "{type} at the event's end" : "{type} am Ende des Ereignisses",
    "Audio alarm at {time}" : "Audio-Alarm um {time}",
    "Pop-up at {time}" : "Pop-Up-Meldung um {time}",
    "Email at {time}" : "E-Mail um {time}",
    "None at {time}" : "Keine Aktion um {time}",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere deinen Administrator für weitere Informationen.",
    "Title of the Event" : "Titel des Ereignisses",
    "Starts" : "Beginnt",
    "Ends" : "Endet",
    "All day Event" : "Ganztägiges Ereignis",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr …",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Ereignisstatus",
    "Visibility when sharing" : "Sichtbarkeit wenn geteilt",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen Dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
    "We wanted to inform you that %s has published the calendar %s." : "Wir möchten Dich darüber informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicke auf den Link unten, um darauf zuzugreifen",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfe die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender teilen",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "iCal link" : "iCal-Link",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "Neues Abonnement",
    "Go back" : "Zurück",
    "Go forward" : "Weiter",
    "Calendar does not exist" : "Kalender existiert nicht",
    "Maybe you got a wrong link or the calendar was unshared?" : "Möglicherweise hast Du einen falschen Link erhalten oder die Freigabe des Kalenders wurde aufgehoben",
    "Edit event" : "Ereignis bearbeiten",
    "Delete Event" : "Ereignis löschen",
    "Save Event" : "Ereignis speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "E-Mail-Erinnerungen wurden bisher noch nicht im CalDAV-Server umgesetzt. Daher werden aktuell keine E-Mail-Erinnerungen gesendet.",
    "Add" : "Hinzufügen",
    "Email address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte füge Deine E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Ereignisses wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt werden.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederholen jeden …",
    "end repeat ..." : "Wiederholung beenden …",
    "times" : "Mal",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "%s shared the calendar <strong>%s</strong> with you" : "%s hat den Kalender  <strong>%s</strong> mit Dir geteilt",
    "Embed" : "Einbetten",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Publish URL" : "URL veröffentlichen",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Keine Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse",
    "Subscribe" : "Abonnieren"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Wir möchten Dich informieren, dass %s den Kalender »%s« veröffentlicht hat.",
    "Open »%s«" : "»%s« öffnen",
    "Cheers!" : "Noch einen schönen Tag!",
    "Recipient" : "Empfänger",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} Fehler)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "Individual" : "Einzelperson",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), es wird auf UTC geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neues Ereignis",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfe die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender teilen",
    "Shared" : "Geteilt",
    "Could not save WebCal-calendar" : "Der WebCal-Kalender konnte nicht gespeichert werden",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "Email sent." : "E-Mail gesendet.",
    "Could not send your email." : "E-Mail konnte nicht versandt werden.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "Wenn geteilt, zeige das vollständige Ereignis an",
    "When shared show only busy" : "wenn geteilt, zeige nur den Status 'beschäftigt' an",
    "When shared hide this event" : "Wenn geteilt, zeige das Ereignis nicht an",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgesagt",
    "Please add a title." : "Bitte einen Titel hinzufügen.",
    "Please select a calendar." : "Bitte einen Kalender auswählen.",
    "The event can not end before it starts." : "Das Ereignis endet bevor es startet.",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "Jeden Tag",
    "Every week" : "Jede Woche",
    "Every month" : "Jeden Monat",
    "Every year" : "Jedes Jahr",
    "never" : "Niemals",
    "after" : "Nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn du damit beginnen würdest einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Ereignisses",
    "5 minutes before" : "5 Minuten vorher",
    "10 minutes before" : "10 Minuten vorher",
    "15 minutes before" : "15 Minuten vorher",
    "30 minutes before" : "30 Minuten vorher",
    "1 hour before" : "1 Stunde vorher",
    "2 hours before" : "2 Stunden vorher",
    "Custom" : "Benutzerdefiniert",
    "Audio" : "Audio",
    "Email" : "E-Mail",
    "Pop-up" : "Pop-up",
    "sec" : "Sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported {imported} objects" : "Erfolgreich {imported} Objekte importiert ",
    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} von {all} importiert, ein Duplikat übersprungen",
    "Imported {imported} out of {all}, one failure" : "{imported} von {all} importiert, ein Fehler",
    "Imported {imported} out of {all}, {errors} failures" : "{imported} von {all} importiert, {errors} Fehler",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {duplicates} Duplikate übersprungen",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {errors} Fehler, {duplicates} Duplikate übersprungen",
    "Audio alarm {time} before the event starts" : "Audio-Alarm {time} bevor das Ereignis startet",
    "Pop-up {time} before the event starts" : "Pop-Up-Meldung {time} bevor das Ereignis startet",
    "Email {time} before the event starts" : "E-Mail {time} bevor das Ereignis startet",
    "None {time} before the event starts" : "Keine Aktion {time} bevor das Ereignis startet",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
    "Audio alarm {time} before the event ends" : "Audio-Alarm {time} bevor das Ereignis endet",
    "Pop-up {time} before the event ends" : "Pop-Up-Meldung {time} bevor das Ereignis endet",
    "Email {time} before the event ends" : "E-Mail {time} bevor das Ereignis endet",
    "None {time} before the event ends" : "Keine Aktion {time} bevor das Ereignis endet",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
    "Audio alarm {time} after the event starts" : "Audio-Alarm {time} nachdem das Ereignis startet",
    "Pop-up {time} after the event starts" : "Pop-Up-Meldung {time} nachdem das Ereignis startet",
    "Email {time} after the event starts" : "E-Mail {time} nachdem das Ereignis startet",
    "None {time} after the event starts" : "Keine Aktion {time} nachdem das Ereignis startet",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
    "Audio alarm {time} after the event ends" : "Audio-Alarm {time} nachdem das Ereignis endete",
    "Pop-up {time} after the event ends" : "Pop-Up-Meldung {time} nachdem das Ereignis endete",
    "Email {time} after the event ends" : "E-Mail {time} nachdem das Ereignis endete",
    "None {time} after the event ends" : "Keine Aktion {time} nachdem das Ereignis endete",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
    "Audio alarm at the event's start" : "Audio-Alarm beim Start des Ereignisses",
    "Pop-up at the event's start" : "Pop-Up-Meldung beim Start des Ereignisses",
    "Email at the event's start" : "E-Mail beim Start des Ereignisses",
    "None at the event's start" : "Keine Aktion beim Start des Ereignisses",
    "{type} at the event's start" : "{type} zu Beginn der Ereignisses",
    "Audio alarm at the event's end" : "Audio-Alarm beim Ende des Ereignisses",
    "Pop-up at the event's end" : "Pop-Up-Meldung beim Ende des Ereignisses",
    "Email at the event's end" : "E-Mail beim Ende des Ereignisses",
    "None at the event's end" : "Keine Aktion beim Ende des Ereignisses",
    "{type} at the event's end" : "{type} am Ende des Ereignisses",
    "Audio alarm at {time}" : "Audio-Alarm um {time}",
    "Pop-up at {time}" : "Pop-Up-Meldung um {time}",
    "Email at {time}" : "E-Mail um {time}",
    "None at {time}" : "Keine Aktion um {time}",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere deinen Administrator für weitere Informationen.",
    "Title of the Event" : "Titel des Ereignisses",
    "Starts" : "Beginnt",
    "Ends" : "Endet",
    "All day Event" : "Ganztägiges Ereignis",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr …",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Ereignisstatus",
    "Visibility when sharing" : "Sichtbarkeit wenn geteilt",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen Dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
    "We wanted to inform you that %s has published the calendar %s." : "Wir möchten Dich darüber informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicke auf den Link unten, um darauf zuzugreifen",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "iCal link" : "iCal-Link",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "Neues Abonnement",
    "Go back" : "Zurück",
    "Go forward" : "Weiter",
    "Calendar does not exist" : "Kalender existiert nicht",
    "Maybe you got a wrong link or the calendar was unshared?" : "Möglicherweise hast Du einen falschen Link erhalten oder die Freigabe des Kalenders wurde aufgehoben",
    "Edit event" : "Ereignis bearbeiten",
    "Delete Event" : "Ereignis löschen",
    "Save Event" : "Ereignis speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-Mail-Erinnerungen wurden bisher nicht im CalDAV-Server umgesetzt, daher werden keine versendet.",
    "Add" : "Hinzufügen",
    "Email address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte füge Deine E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Ereignisses wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt werden.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederholen jeden …",
    "end repeat ..." : "Wiederholung beenden …",
    "times" : "Mal",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "%s shared the calendar <strong>%s</strong> with you" : "%s hat den Kalender  <strong>%s</strong> mit Dir geteilt",
    "Embed" : "Einbetten",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Publish URL" : "URL veröffentlichen",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Keine Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse",
    "Subscribe" : "Abonnieren"
},
"nplurals=2; plural=(n != 1);");
